summaryrefslogtreecommitdiffstats
path: root/tderesources/groupwise/soap
diff options
context:
space:
mode:
Diffstat (limited to 'tderesources/groupwise/soap')
-rw-r--r--tderesources/groupwise/soap/groupwiseserver.cpp2
-rw-r--r--tderesources/groupwise/soap/groupwiseserver.h2
-rw-r--r--tderesources/groupwise/soap/gwconverter.cpp12
-rw-r--r--tderesources/groupwise/soap/incidenceconverter.cpp6
-rw-r--r--tderesources/groupwise/soap/ksslsocket.cpp6
-rw-r--r--tderesources/groupwise/soap/ksslsocket.h2
-rw-r--r--tderesources/groupwise/soap/stdsoap2.cpp3
-rw-r--r--tderesources/groupwise/soap/stdsoap2.h31
8 files changed, 19 insertions, 45 deletions
diff --git a/tderesources/groupwise/soap/groupwiseserver.cpp b/tderesources/groupwise/soap/groupwiseserver.cpp
index 07342ec4..3ba461b9 100644
--- a/tderesources/groupwise/soap/groupwiseserver.cpp
+++ b/tderesources/groupwise/soap/groupwiseserver.cpp
@@ -114,7 +114,7 @@ int GroupwiseServer::gSoapOpen( struct soap *soap, const char *,
// kdDebug() << "Creating KSSLSocket()" << endl;
m_sock = new KSSLSocket();
m_sock->setTimeout( KProtocolManager::connectTimeout() );
- connect( m_sock, TQT_SIGNAL( sslFailure() ), TQT_SLOT( slotSslError() ) );
+ connect( m_sock, TQ_SIGNAL( sslFailure() ), TQ_SLOT( slotSslError() ) );
} else {
m_sock = new KExtendedSocket();
}
diff --git a/tderesources/groupwise/soap/groupwiseserver.h b/tderesources/groupwise/soap/groupwiseserver.h
index 0a0f70e0..31cd8f14 100644
--- a/tderesources/groupwise/soap/groupwiseserver.h
+++ b/tderesources/groupwise/soap/groupwiseserver.h
@@ -93,7 +93,7 @@ class DeltaInfo
class GroupwiseServer : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
diff --git a/tderesources/groupwise/soap/incidenceconverter.cpp b/tderesources/groupwise/soap/incidenceconverter.cpp
index 84e28e69..5491f3db 100644
--- a/tderesources/groupwise/soap/incidenceconverter.cpp
+++ b/tderesources/groupwise/soap/incidenceconverter.cpp
@@ -543,7 +543,7 @@ bool IncidenceConverter::convertFromCalendarItem( ngwt__CalendarItem* item,
std::vector<xsd__date>::const_iterator it;
for ( it = dateList->begin(); it != dateList->end(); ++it ) {
- TQDate date = TQDate::fromString( s2q( *it ), Qt::ISODate );
+ TQDate date = TQDate::fromString( s2q( *it ), TQt::ISODate );
if ( date.isValid() )
}
}
@@ -689,7 +689,7 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
// recurrence date - try setting it using the recurrence start date - didn't help
/* std::string startDate;
- startDate.append( recur->recurStart().date().toString( Qt::ISODate ).utf8() );
+ startDate.append( recur->recurStart().date().toString( TQt::ISODate ).utf8() );
item->rdate = soap_new_ngwt__RecurrenceDateType( soap(), -1 );
item->rdate->date.push_back( startDate );*/
// exceptions list - try sending empty list even if no exceptions
@@ -704,7 +704,7 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
for ( KCal::DateList::ConstIterator it = exceptions.begin(); it != exceptions.end(); ++it )
{
std::string startDate;
- startDate.append( TQString((*it).toString( Qt::ISODate )).utf8() );
+ startDate.append( TQString((*it).toString( TQt::ISODate )).utf8() );
item->exdate->date.push_back( startDate );
}
}
diff --git a/tderesources/groupwise/soap/ksslsocket.cpp b/tderesources/groupwise/soap/ksslsocket.cpp
index 2f085cf2..b753249d 100644
--- a/tderesources/groupwise/soap/ksslsocket.cpp
+++ b/tderesources/groupwise/soap/ksslsocket.cpp
@@ -57,9 +57,9 @@ KSSLSocket::KSSLSocket() : KExtendedSocket()
setBlockingMode(false);
//Connect internal slots
- TQObject::connect( this, TQT_SIGNAL(connectionSuccess()), this, TQT_SLOT(slotConnected()) );
- TQObject::connect( this, TQT_SIGNAL(closed(int)), this, TQT_SLOT(slotDisconnected()) );
- TQObject::connect( this, TQT_SIGNAL(connectionFailed(int)), this, TQT_SLOT(slotDisconnected()));
+ TQObject::connect( this, TQ_SIGNAL(connectionSuccess()), this, TQ_SLOT(slotConnected()) );
+ TQObject::connect( this, TQ_SIGNAL(closed(int)), this, TQ_SLOT(slotDisconnected()) );
+ TQObject::connect( this, TQ_SIGNAL(connectionFailed(int)), this, TQ_SLOT(slotDisconnected()));
}
KSSLSocket::~KSSLSocket()
diff --git a/tderesources/groupwise/soap/ksslsocket.h b/tderesources/groupwise/soap/ksslsocket.h
index 42545948..aa4225b8 100644
--- a/tderesources/groupwise/soap/ksslsocket.h
+++ b/tderesources/groupwise/soap/ksslsocket.h
@@ -27,7 +27,7 @@ class KSSLSocketPrivate;
class KSSLSocket : public KExtendedSocket
{
- Q_OBJECT
+ TQ_OBJECT
public:
diff --git a/tderesources/groupwise/soap/stdsoap2.cpp b/tderesources/groupwise/soap/stdsoap2.cpp
index b83b2bb4..e3d42998 100644
--- a/tderesources/groupwise/soap/stdsoap2.cpp
+++ b/tderesources/groupwise/soap/stdsoap2.cpp
@@ -3827,9 +3827,6 @@ soap_accept(struct soap *soap)
#elif defined(PALM)
fcntl((SOAP_SOCKET)soap->master, F_SETFL, fcntl((SOAP_SOCKET)soap->master, F_GETFL,0)&~O_NONBLOCK);
fcntl((SOAP_SOCKET)soap->socket, F_SETFL, fcntl((SOAP_SOCKET)soap->socket, F_GETFL,0)&~O_NONBLOCK);
-#elif defined(SYMBIAN)
- long blocking = 0;
- ioctl((SOAP_SOCKET)soap->master, 0/*FIONBIO*/, &blocking);
#else
fcntl((SOAP_SOCKET)soap->master, F_SETFL, fcntl((SOAP_SOCKET)soap->master, F_GETFL)&~O_NONBLOCK);
fcntl((SOAP_SOCKET)soap->socket, F_SETFL, fcntl((SOAP_SOCKET)soap->socket, F_GETFL)&~O_NONBLOCK);
diff --git a/tderesources/groupwise/soap/stdsoap2.h b/tderesources/groupwise/soap/stdsoap2.h
index b68c2407..adb5037b 100644
--- a/tderesources/groupwise/soap/stdsoap2.h
+++ b/tderesources/groupwise/soap/stdsoap2.h
@@ -153,11 +153,6 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
# endif
#endif
-#ifdef __SYMBIAN32__
-# define SYMBIAN
-# undef WIN32
-#endif
-
#if defined(__palmos__) || defined(PALM_GCC) || defined(__PALMOS_TRAPS__)
# ifndef PALM
# define PALM
@@ -333,12 +328,6 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
# define O_NONBLOCK FNONBIO
# include <sys_socket.h>
# include "palmFunctions.h"
-# elif defined(SYMBIAN)
-# define WITH_LEAN
-# define WITH_NONAMESPACES
-# define HAVE_STRTOD /* use STRTOD since sscanf doesn't seem to work */
-# include <e32def.h>
-# include <sys/ioctl.h>
# elif defined(VXWORKS)
# define HAVE_STRRCHR
# define HAVE_STRTOD
@@ -445,9 +434,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
# include <sockLib.h>
# endif
# ifndef VXWORKS
-# ifndef SYMBIAN
-# include <strings.h>
-# endif
+# include <strings.h>
# endif
# ifdef SUN_OS
# include <sys/stream.h> /* SUN */
@@ -565,10 +552,7 @@ extern "C" {
#define SOAP_INVALID_SOCKET (-1)
#define soap_valid_socket(n) ((n) != SOAP_INVALID_SOCKET)
-#if defined(SYMBIAN)
-# define LONG64 long
-# define ULONG64 unsigned LONG64
-#elif !defined(WIN32) || defined(__GLIBC__) || defined(__GNU__)
+#if !defined(WIN32) || defined(__GLIBC__) || defined(__GNU__)
# ifndef LONG64
# define LONG64 long long
# define ULONG64 unsigned LONG64
@@ -583,8 +567,6 @@ extern "C" {
#if defined(WIN32)
# define soap_int32 __int32
-#elif defined(SYMBIAN)
-# define soap_int32 long
#elif defined(PALM)
# define soap_int32 Int32
#else
@@ -601,13 +583,8 @@ extern "C" {
# define SOAP_ERANGE ERANGE
# define SOAP_EINTR EINTR
# define SOAP_EAGAIN EAGAIN
-# ifdef SYMBIAN
-# define SOAP_EWOULDBLOCK 9898
-# define SOAP_EINPROGRESS 9899
-# else
-# define SOAP_EWOULDBLOCK EWOULDBLOCK
-# define SOAP_EINPROGRESS EINPROGRESS
-# endif
+# define SOAP_EWOULDBLOCK EWOULDBLOCK
+# define SOAP_EINPROGRESS EINPROGRESS
#endif
#ifdef WIN32
diff --git a/tderesources/groupwise/soap/gwconverter.cpp b/tderesources/groupwise/soap/gwconverter.cpp
index bda455f7..b842f15b 100644
--- a/tderesources/groupwise/soap/gwconverter.cpp
+++ b/tderesources/groupwise/soap/gwconverter.cpp
@@ -67,8 +67,8 @@ char* GWConverter::qStringToChar( const TQString &string )
TQDate GWConverter::charToTQDate( const char *str )
{
- if ( !str ) return TQDate(); // FIXME: Qt::ISODate is probably no good here because it expects yyyy-MM-dd not yyyyMMdd
- return TQDate::fromString( TQString::fromUtf8( str ), Qt::ISODate );
+ if ( !str ) return TQDate(); // FIXME: TQt::ISODate is probably no good here because it expects yyyy-MM-dd not yyyyMMdd
+ return TQDate::fromString( TQString::fromUtf8( str ), TQt::ISODate );
}
char *GWConverter::qDateTimeToChar( const TQDateTime &dt,
@@ -94,7 +94,7 @@ std::string* GWConverter::qDateTimeToString( const TQDateTime &dt )
TQDateTime GWConverter::stringToTQDateTime( const std::string* str )
{
- TQDateTime dt = TQDateTime::fromString( TQString::fromUtf8( str->c_str() ), Qt::ISODate );
+ TQDateTime dt = TQDateTime::fromString( TQString::fromUtf8( str->c_str() ), TQt::ISODate );
return dt;
}
@@ -111,15 +111,15 @@ std::string* GWConverter::qDateToString( const TQDate &date )
TQDate GWConverter::stringToTQDate( std::string* str )
{
//NB this ISODate may become unnecessary, if GW stops sending in yyyy-mm-dd format again
- return TQDate::fromString( TQString::fromLatin1( str->c_str() ), Qt::ISODate );
+ return TQDate::fromString( TQString::fromLatin1( str->c_str() ), TQt::ISODate );
}
TQDateTime GWConverter::charToTQDateTime( const char *str )
{
if ( !str ) return TQDateTime();
// kdDebug() << "charToTQDateTime(): " << str << endl;
- // as above re Qt::ISODate
- TQDateTime dt = TQDateTime::fromString( TQString::fromUtf8( str ), Qt::ISODate );
+ // as above re TQt::ISODate
+ TQDateTime dt = TQDateTime::fromString( TQString::fromUtf8( str ), TQt::ISODate );
// kdDebug() << " " << dt.toString() << endl;
return dt;
}